#' Generate matrix of qsvs
#'
#'  Using the pcs and the k number of components be included,
#'  we generate the qsva matrix.
#'
#'
#' @param qsvPCs prcomp object generated by taking
#' the pcs of degraded transcripts
#' @param k number of qsvs to be included.
#'
#' @return matrix with k principal components for each sample.
#' @export
#'
#' @examples
#' qsv <- list(x = matrix(seq_len(9), ncol = 3))
#' get_qsvs(qsv, 2)
get_qsvs <- function(qsvPCs, k) {
    # check that k isn't zero
    qSVs <- qsvPCs$x[, seq_len(k), drop = FALSE]
    colnames(qSVs) <- paste0("qSV", seq_len(k))
    return(qSVs)
}
